requires ti.targets;

/*!
 *  ======== local.targets ========
 *  This package contains several examples of arm targets based on the TI
 *  codegen tools.
 *
 *  This package illustrates how one can create custom targets *without*
 *  making any changes to the xdc tool set.  This means that the developer is
 *  never dependent on "external" developers for updates to the xdc tools in
 *  order to build libraries with respect to special targets.
 *
 *  This package contains the following modules:
 *
 *	TIArm9    this module represents a little endian Arm9 ti_arm9_abi
 *		  target.  Because this module inherits from the
 *		  ti.targets.ITarget interface, there is no need to implement
 *		  any of the xdc.bld.ITarget functions (the implementations
 *		  in ti.targets.ITarget are sufficient).
 *
 *	TIArm11 - this module represents a little endian Arm11 ti_arm9_abi
 *		  target.  In this case, we inherit from the ITIArm interface
 *		  (defined in this package) to show how to "share" common
 *		  settings amoung multiple modules.  Again, there is no
 *		  implementation required for this module.
 *
 *	TIArm11D - this module is exactly the same as TIArm11 above except
 *		   that it prints a message whenever one of its methods is
 *		   called.  This module illustrates how one can override the
 *		   implementations contained in the inherited interfaces to
 *		   create customized target behavior; see the implementation
 *		   file TIArm11D.xs
 *
 *  This package contains the following interfaces:
 *
 *	ITIArm	- this interface is used by the TIArm11 and TIArm11D modules
 *		  described above.  Its sole purpose is to encapsulate
 *		  commonality between multiple targets defined in this
 *		  package; in this case, TIArm11 and TIArm11D.  We could
 *		  have used this interface with TIArm9 but choose not to
 *		  for pedagogic reasons.
 *
 */
package local.targets [1, 0, 0]
{
    module TIArm9;

    interface ITIArm;
    module TIArm11, TIArm11D;
}
